<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>트레이 아이콘 클릭&#xa0;
또는 단축키를 다시 눌러 녹화를 중지하십시오</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>녹화 중 화면을 회전하지 마세요</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>녹화</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>저장하지 못했습니다. 홈 디렉토리에 저장하십시오.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>스크린샷 완료</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>선택 영역</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>무시</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>클립보드</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>화면 녹화 파일을 저장 중입니다, 잠시 기다려 주세요...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>녹화 과정 중 창 효과가 비활성화되어 있기 때문에 녹화를 중단해야 합니다</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>스크롤샷</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>고정 화면 캡처</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>화면 캡처 완료 및 클립보드에 복사</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>고정 화면 캡처</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>녹화</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>녹화 중</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>녹화 완료</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>폴더 열기</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>화면 캡처는 %1초에 시작됩니다</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>도움말을 확인하세요.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>지속적인 화면 캡처 실패</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>스크롤 영역의 하단에 도달했습니다</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>최대 길이에 도달했어요</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>캡처 영역 조정</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>마우스 휠을 스크롤하거나 클릭하여 스크롤 화면 캡처를 수행하세요</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>스크롤 속도를 줄이세요</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>잘못된 영역, 클릭하여 </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>여기에 텍스트 입력</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>시작/스크린샷</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>종료/저장</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>크기 조정</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>빠른 시작</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>창 스크린샷</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>지연 스크린샷</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>전체 스크린샷</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>높이 위로 증가</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>높이 아래로 증가</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>왼쪽 너비 증가</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>오른쪽 너비 증가</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>높이 위로 감소</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>높이 아래로 감소</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>왼쪽 너비 감소</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>오른쪽 너비 감소</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>음성</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>키 입력</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>웹캠</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>녹화 시작</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>시작/녹화</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>마우스</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>도구</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>텍스트 추출</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>스크롤샷</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>스크린샷 고정</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>OCR 시작</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>스크롤샷 시작</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>녹화</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>|-
 사각형
 Shift를 누르고 놓아 정사각형을 그립니다</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>|-
 타원
 Shift를 누르고 놓아 원을 그립니다</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>|-
 붓
 Shift를 누르고 놓아 직선을 그립니다</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>흐림 강도 조정 (스크롤하여 조정)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>붓 크기 조정 (스크롤하여 조정)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>텍스트 크기 조정 (스크롤하여 조정)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>키스트로크 표시 (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>키스트로크 숨기기 (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>키스트로크 표시 (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>카메라 켜기 (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>카메라 끄기 (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>설정 (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>형식:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>음성</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>마이크</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>시스템 음성</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>포인터 표시</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>클릭 표시</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>저장 위치</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>바탕화면</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>비디오</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>|-
 선 (L)
 Shift를 누르고 놓아 수직 또는 수평 선을 그립니다</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>화살표 (X)
Shift를 누르고 놓아 수직 또는 수평 화살표를 그립니다</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>연필 (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>흐리게 하기 (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>텍스트 (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>스크롤샷 (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>텍스트 추출 (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>스크린샷 고정 (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>실행 취소 (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>저장 시 경로 설정</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>저장 시 경로 변경</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>테두리 효과</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>그림자</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>테두리</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>장치</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>텍스트 추출</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>도형 도구 (R)
Shift 키를 누른 채로 정사각형이나 원을 그립니다.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>로컬에 저장</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>바탕화면에 저장</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>사진에 저장</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>%1에 저장</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>지정된 위치</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>사용자 지정 위치</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>각 조회</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>저장 시 위치 업데이트</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>바탕화면에 저장</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>사진에 저장</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>닫기 (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>클립보드에 복사 (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> %1*%2 내에서 녹화 영역을 조정하여 더 나은 영상 효과를 얻을 수 있습니다</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>현재 화면 녹화 기능은 지원되지 않습니다</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
</TS>
